function [crit_al,crit_t]=fuller_tab(p,T)
 
// PURPOSE: compute Fuller(1976) tables
// ------------------------------------------------------------
// INPUT:
// * p = order of the polynomial trend
// * T = # of observations
// ------------------------------------------------------------
// OUTPUT:
// * crit_al == (1% - 5% -10%) critical values of the
//   rho test
// * crit_t == (1% - 5% -10%) critical values of the
//   tau test
// ------------------------------------------------------------
// REFERENCE:
// Fuller(1976) : Introduction to Statistical Time Series, New
// York: Wiley
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
// http://grocer.toolbox.free.fr/grocer.html
 
 
// store the Fuller (1976) tables
select p
case -1 then
   mat_al=[0 0.01 0.05 0.1 ;
           25 -11.9 -7.3 -5.3 ;...
           50 -12.9 -7.7 -5.5 ;...
           100 -13.3 -7.9 -5.6 ;...
           250 -13.6 -8.0 -5.7 ;...
           500 -13.7 -8.0 -5.7 ;...
           1500 -13.8 -8.1 -5.7 ]
// N.B : infinity is assumed to be attained at T=1500
   mat_t=[0 0.01 0.05 0.1 ;
          25 -2.66 -1.95 -1.60 ;...
          50 -2.62 -1.95 -1.61 ;...
          100 -2.60 -1.95 -1.61 ;...
          250 -2.58 -1.95 -1.62 ;...
          500 -2.58 -1.95 -1.62 ;...
          1500 -2.58 -1.95 -1.62 ]
case 0 then
   mat_al=[0 0.01 0.05 0.1 ;
           25 -17.2 -12.5 -10.2 ;...
           50 -18.9 -13.3 -10.7 ;...
           100 -19.8 -13.7 -11.0 ;...
           250 -20.3 -14.0 -11.2 ;...
           500 -20.5 -14.0 -11.2 ;...
           1500 -20.7 -14.1 -11.3 ]
   mat_t=[0 0.01 0.05 0.1 ;
          25 -3.75 -3.00 -2.63 ;...
          50 -3.58 -2.93 -2.60 ;...
          100 -3.51 -2.89 -2.58 ;...
          250 -3.46 -2.88 -2.57 ;...
          500 -3.44 -2.87 -2.57 ;...
          1500 -3.43 -2.86 -2.57 ]
case 1 then
   mat_al=[0 0.01 0.05 0.1 ;
           25 -22.5 -17.9 -15.6 ;...
           50 -57.7 -19.8 -16.8 ;...
           100 -27.4 -20.7 -17.5 ;...
           250 -28.4 -21.3 -18.0 ;...
           500 -28.9 -21.5 -18.1 ;...
           1500 -29.5 -21.8 -18.3 ]
   mat_t=[0 0.01 0.05 0.1 ;
          25 -4.38 -3.60 -3.24 ;...
          50 -4.15 -3.50 -3.18 ;...
          100 -4.04 -3.45 -3.15 ;...
          250 -3.99 -3.43 -3.13 ;...
          500 -3.98 -3.42 -3.13 ;...
          1500 -3.96 -3.41 -3.12 ]
end
 
// interpolate the tables
crit_al=extraptab(mat_al,T)
crit_t=extraptab(mat_t,T)
 
endfunction
