function y = recsercp(x,z)
 
// PURPOSE: mimics gauss function recsercp: computes a
// recursive series involving products
//--------------------------------------------------------
// INPUT:
// * x = a matrix or vector of dimensions (n,k)
// * z = a matrix or vector of same dimensions
//--------------------------------------------------------
// OUTPUT:
// y = (N x K) matrix in which each column is a series
//     generated by a recursion of the form:
//     y(1) = x(1) + z(1)
//     y(t) = y(t - 1)*x(t) + z(t), t = 2, ...N
//--------------------------------------------------------
// Copyright Eric Dubois 2010
// http://grocer.toolbox.free.fr/grocer.html
// translated and adapted from a matlab program by:
// Kit Baum
// Dept of Economics
// Boston College
// Chestnut Hill MA 02467 USA
// baum@bc.edu
// 9525
 
if %nargin~=2 then
  error("Wrong number of arguments");
end;
[n1,k1] = size(x);
[n2,k2] = size(z);
if n1~=n2 then
  error("arguments must have same number of rows");
end;
if k1~=k2 then
  error("arguments must have same number of columns");
end;
y = zeros(n1,k1);
y(1,:) = x(1,:)+z(1,:);
 
for j = 2:n1
  y(j,:) = y(j-1,:) .*x(j,:)+z(j,:);
end;
 
endfunction
