function resout=deriv_func(reseq)
 
// PURPOSE: breaks down an equation into elementary bricks
// ------------------------------------------------------------
// INPUT:
// * reseq = an 'equation' tlist, the result of the breaking
//   down of an equation into elementary bricks
// ------------------------------------------------------------
// OUTPUT:
// * resout = an 'equation tlist', the derivative of the original
//   equation, expressed as elementary bricks
// ------------------------------------------------------------
// Copyright: Eric Dubois 2011
// http://grocer.toolbox.free.fr/grocer.html
 
func=reseq('name func')
ind_func=find(grocer_listfunctions == func)
deriv=deriv_eq1(reseq('input'),vari)
 
scal=%f
zero=%f
if deriv('type') == 'scalar' then
   scal=%t
   if deriv('val') == '0' then
      zero=%t
   end
end
 
if zero then
   resout=tlist(['equation';'type';'val'],'scalar','0')
 
elseif ind_func <= size(grocer_listderivatives,'*') then
   deriv_func_i=grocer_listderivatives(ind_func)
   resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
                 tlist(['equation';'type';'exp'],'parentheses',...
                 deriv_eq1(reseq('input'),vari)),' .*',...
                 tlist(['equation';'type';'name func';'input'],'function',...
                 deriv_func_i,reseq('input')))
 
else
   select func
   case 'acos' then
       resout=tlist(['equation';'type';'operator';'rhs'],'unary',...
              '-',tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'name func';'input'],'function','sqrt',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','1'),'-',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              reseq('input')),' .^',tlist(['equation';'type';'val'],'scalar','2'))))))
 
   case 'acosh' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'name func';'input'],'function','sqrt',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              reseq('input')),' .^',tlist(['equation';'type';'val'],'scalar','2')),'-',...
              tlist(['equation';'type';'val'],'scalar','1'))))
 
   case 'asin' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'name func';'input'],'function','sqrt',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','1'),'-',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              reseq('input')),' .^',tlist(['equation';'type';'val'],'scalar','2')))))
 
   case 'asinh' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'name func';'input'],'function','sqrt',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              reseq('input')),' .^',tlist(['equation';'type';'val'],'scalar','2')),'+',...
              tlist(['equation';'type';'val'],'scalar','1'))))
 
   case 'atan' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'exp'],'parentheses',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              reseq('input')),' .^',tlist(['equation';'type';'val'],'scalar','2')),'+',...
              tlist(['equation';'type';'val'],'scalar','1'))))
 
   case 'atanh' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'exp'],'parentheses',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','1'),'-',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              reseq('input')),' .^',tlist(['equation';'type';'val'],'scalar','2')))))
 
   case 'cos' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'operator';'rhs'],'unary',...
              '-',tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari))),' .*',...
              tlist(['equation';'type';'name func';'input'],'function',...
              'sin',reseq('input')))
 
   case 'cotg' then
       resout=tlist(['equation';'type';'operator';'rhs'],'unary',...
              '-',tlist(['equation';'type';'lhs';'operator';'rhs'],...
              'operation',tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' .*',...
              tlist(['equation';'type';'exp'],'parentheses',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','1'),'+',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              reseq,' .^',tlist(['equation';'type';'val'],'scalar','2'))))))
 
   case 'log' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'exp'],'parentheses',reseq('input')))
 
   case 'log10' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' ./',...
              tlist(['equation';'type';'exp'],'parentheses',reseq('input'))),'/',...
              tlist(['equation';'type';'name func';'input'],'function',...
              'log',tlist(['equation';'type';'val'],'scalar','10')))
 
   case 'sqrt' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','0.5'),' .*',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari))),' ./',...
              reseq)
 
   case 'tan' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' .*',...
              tlist(['equation';'type';'exp'],'parentheses',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','1'),'+',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              reseq,'^',tlist(['equation';'type';'val'],'scalar','2')))))
 
 
   case 'tanh' then
       resout=tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'exp'],'parentheses',...
              deriv_eq1(reseq('input'),vari)),' .*',...
              tlist(['equation';'type';'exp'],'parentheses',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              tlist(['equation';'type';'val'],'scalar','1'),'-',...
              tlist(['equation';'type';'lhs';'operator';'rhs'],'operation',...
              reseq,'^',tlist(['equation';'type';'val'],'scalar','2')))))
 
   end
 
end
 
endfunction
